# Copyright (C) 2010 A. S. Budden
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

import os
from bzrlib.commands import Command
from bzrlib.option import Option

from bzrlib.config import (
        GlobalConfig,
        ensure_config_dir_exists,
        )

from bzrlib.plugins.custom_url_schemes import GetCustomSchemes

def WriteCustomSchemes(scheme_dict):
    config = GlobalConfig()
    parser = config._get_parser()
    parser['Custom URL Schemes'] = {}
    for name, command in scheme_dict.items():
        parser['Custom URL Schemes'][name] = command

    def save_config(config, parser):
        ensure_config_dir_exists(os.path.dirname(config._get_filename()))
        f = open(config._get_filename(), 'wb')
        parser.write(f)
        f.close()
    
    save_config(config, parser)

class cmd_custom_url_scheme_add(Command):
    """Add a new URL scheme.
    """
    takes_args = ['short_name', 'full_url']

    def run(self, short_name, full_url):

        while short_name.endswith(':'):
            short_name = short_name[:-1]

        custom_schemes = GetCustomSchemes()

        custom_schemes[short_name] = full_url
        
        WriteCustomSchemes(custom_schemes)

class cmd_custom_url_scheme_remove(Command):
    """Remove an existing URL scheme.
    """
    takes_args = ['short_name']

    def run(self, short_name):
        while short_name.endswith(':'):
            short_name = short_name[:-1]

        custom_schemes = GetCustomSchemes()

        if not custom_schemes.has_key(short_name):
            raise errors.BzrCommandError('URL Scheme %s does not exist' % short_name)

        del(custom_schemes[short_name])

        WriteCustomSchemes(custom_schemes)

class cmd_custom_url_scheme_list(Command):
    """ List existing URL schemes.
    """
    def run(self):
        custom_schemes = GetCustomSchemes()

        self.outf.write("Custom URL Schemes:\n")
        for name, command in custom_schemes.items():
            self.outf.write("    %s -> %s\n" % (name, command))

